@@ -1285,9 +1285,8 @@ glamor_buffer_glyph(glamor_screen_private *glamor_priv,
                  * thus we have to composite from the cache picture
                  * to the cache picture, we need a flush here to make
                  * sure latter we get the corret glyphs data.*/
-                glamor_get_context(glamor_priv);
+                glamor_make_current(glamor_priv);
                 glFlush();
-                glamor_put_context(glamor_priv);
             }
         }
         else {
